import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MapList } from '../model/mapList';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class MapService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Finds all maps
     * All maps
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAllMaps(observe?: 'body', reportProgress?: boolean): Observable<MapList>;
    getAllMaps(observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MapList>>;
    getAllMaps(observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MapList>>;
    /**
     * Finds a map based on map ID
     * A map information
     * @param mapId ID of map to return
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getMap(mapId: number, observe?: 'body', reportProgress?: boolean): Observable<any>;
    getMap(mapId: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    getMap(mapId: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Finds a map based on map ID with custom stats
     * A map information, with the stats of the trophy range
     * @param mapId ID of map to return
     * @param trophyRange Trophy Range of which return the stats
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getMapWithTrophyRange(mapId: number, trophyRange: '0-299' | '300-599' | '600+', observe?: 'body', reportProgress?: boolean): Observable<any>;
    getMapWithTrophyRange(mapId: number, trophyRange: '0-299' | '300-599' | '600+', observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    getMapWithTrophyRange(mapId: number, trophyRange: '0-299' | '300-599' | '600+', observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MapService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MapService>;
}
